@@ -1,6 +1,6 @@
 /*
  * tst_basic.c - self-tests for liboath basic functions
- * Copyright (C) 2009-2023 Simon Josefsson
+ * Copyright (C) 2009-2024 Simon Josefsson
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -57,6 +57,12 @@ main (void)
       return 1;
     }
 
+  if (oath_check_version ("UNKNOWN"))
+    {
+      printf ("oath_check_version (UNKNOWN) didn't fail?!\n");
+      return 1;
+    }
+
   if (OATH_VERSION_NUMBER < 0x02060300 || OATH_VERSION_NUMBER >= 0x03000000)
     {
       printf ("OATH_VERSION_NUMBER out of range?!\n");
