@@ -1,6 +1,6 @@
 /*
  * tst_errors.c - self-tests for libpskc strerror functions
- * Copyright (C) 2012-2023 Simon Josefsson
+ * Copyright (C) 2012-2024 Simon Josefsson
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -46,7 +46,7 @@ main (void)
 	  return 1;
 	}
 
-      printf ("%d: %s: %s\n", i, name, err);
+      printf ("%d: %s: %s\n", i, name ? name : "NONAME", err ? err : "NOERR");
     }
 
   return 0;
